import { Entity, Column, OneToMany, PrimaryGeneratedColumn } from 'typeorm';
import { IsNotEmpty, IsString, IsOptional } from 'class-validator';
import { Song } from '../song/song.entity';

@Entity('album')
export class Album {
  @PrimaryGeneratedColumn()
  id: number;

  @Column({ unique: true })
  @IsString()
  @IsNotEmpty()
  title: string;

  @Column()
  @IsString()
  @IsNotEmpty()
  artist: string;

  @Column()
  @IsString()
  @IsNotEmpty()
  genre: string;

  @IsOptional()
  @OneToMany(() => Song, (song) => song.album, {
    eager: true,
    onDelete: 'CASCADE',
  })
  songs: Song[];
}
